@@ -1,7 +1,10 @@
 from typing import Optional
+from dataclasses import dataclass
+from urllib.parse import urlparse
 
 import google.auth
 from google.auth.transport.requests import AuthorizedSession, Request
+from google.cloud.storage.client import Client
 from google.oauth2.credentials import Credentials
 
 DEFAULT_SCOPES = ['openid', 'email', 'profile', 'https://www.googleapis.com/auth/cloud-platform']
@@ -35,3 +38,26 @@ def authorized_session() -> AuthorizedSession:
 
 def gs_path_from_bucket_prefix(bucket: str, prefix: str) -> str:
     return f"gs://{bucket}/{prefix}"
+
+
+def path_has_any_data(bucket: str, prefix: str, gcs: Client) -> bool:
+    """Checks the given path for any blobs of non-zero size"""
+    blobs = [blob for blob in
+             gcs.list_blobs(bucket, prefix=prefix)]
+    return any([blob.size > 0 for blob in blobs])
+
+
+@dataclass
+class GsBucketWithPrefix:
+    bucket: str
+    prefix: str
+
+    def to_gs_path(self) -> str:
+        return f"gs://{self.bucket}/{self.prefix}"
+
+
+def parse_gs_path(raw_gs_path: str) -> GsBucketWithPrefix:
+    if not raw_gs_path.startswith("gs://"):
+        raise ValueError("GS path must being with gs:// scheme")
+    url_result = urlparse(raw_gs_path)
+    return GsBucketWithPrefix(url_result.netloc, url_result.path[1:])
