@@ -19,6 +19,7 @@ def google_storage_client(_: InitResourceContext) -> storage.Client:
 @dataclass
 class MockBlob:
     name: str
+    size: int
 
     def delete(self) -> None:
         pass
@@ -27,7 +28,7 @@ class MockBlob:
 class MockStorageClient:
     def list_blobs(self, bucket_name: str, prefix: str) -> Iterator[MockBlob]:
         for i in range(0, 10):
-            yield MockBlob(f"fake_blob_{i}")
+            yield MockBlob(f"fake_blob_{i}", 1)
 
 
 @resource
