@@ -9,7 +9,7 @@ from dagster_utils.typing import DagsterConfigDict
 
 class SamResourceTestCase(unittest.TestCase):
     def setUp(self):
-        self.dummy_config: DagsterConfigDict = {'api_url': 'https://zombo.com.fake'}
+        self.dummy_config: DagsterConfigDict = {'api_url': 'https://example.com'}
 
     def test_resource_can_be_initialized_without_extra_config(self):
         with initialize_resource(sam_client, config=self.dummy_config) as client_instance:
@@ -22,5 +22,6 @@ class SamResourceTestCase(unittest.TestCase):
                 client_instance.make_snapshot_public('fake-snapshot-id')
                 mock_authorized_session.put.assert_called_once_with(
                     StringEndingWith('datasnapshot/fake-snapshot-id/policies/reader/public'),
+                    headers={"Content-type": "application/json"},
                     data="true"
                 )
